==> jc-1.4.0.tar.gz: javax/imageio/IIOException.h <==
// public class javax.imageio.IIOException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 360a325ae7243532 javax_imageio_IIOException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_javax_imageio_IIOException_H_
#define _JC_javax_imageio_IIOException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_imageio_IIOException$sub_refs	_jc_javax_imageio_IIOException$sub_refs;
typedef struct _jc_javax_imageio_IIOException$sub_nonrefs	_jc_javax_imageio_IIOException$sub_nonrefs;
typedef struct _jc_javax_imageio_IIOException$refs	_jc_javax_imageio_IIOException$refs;
typedef struct _jc_javax_imageio_IIOException$nonrefs	_jc_javax_imageio_IIOException$nonrefs;
typedef struct _jc_javax_imageio_IIOException$object	_jc_javax_imageio_IIOException$object;

typedef const struct _jc_javax_imageio_IIOException$vmethods	_jc_javax_imageio_IIOException$vmethods;
typedef const struct _jc_javax_imageio_IIOException$vtable	_jc_javax_imageio_IIOException$vtable;
typedef const struct _jc_javax_imageio_IIOException$vtype	_jc_javax_imageio_IIOException$vtype;

// Constructors
extern void _jc_javax_imageio_IIOException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_IIOException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_imageio_IIOException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_imageio_IIOException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_javax_imageio_IIOException$vmethods {
};

// Vtable
struct _jc_javax_imageio_IIOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_imageio_IIOException$vmethods	javax_imageio_IIOException;
};

// Vtype
struct _jc_javax_imageio_IIOException$vtype {
	_jc_type			type;
	_jc_javax_imageio_IIOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_IIOException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_IIOException$refs {
    _jc_javax_imageio_IIOException$sub_refs	javax_imageio_IIOException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_IIOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_IIOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_imageio_IIOException$sub_nonrefs	javax_imageio_IIOException;
};

// Object instance structure
struct _jc_javax_imageio_IIOException$object {
	_jc_javax_imageio_IIOException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_IIOException$vtype	*vtype;
	_jc_javax_imageio_IIOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_IIOException$vtype _jc_javax_imageio_IIOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_IIOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_IIOException$class_object;

#endif	/* _JC_javax_imageio_IIOException_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/IIOException.h <==
// public class javax.imageio.IIOException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 360a325ae7243532 javax_imageio_IIOException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_javax_imageio_IIOException_H_
#define _JC_javax_imageio_IIOException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_imageio_IIOException$sub_refs	_jc_javax_imageio_IIOException$sub_refs;
typedef struct _jc_javax_imageio_IIOException$sub_nonrefs	_jc_javax_imageio_IIOException$sub_nonrefs;
typedef struct _jc_javax_imageio_IIOException$refs	_jc_javax_imageio_IIOException$refs;
typedef struct _jc_javax_imageio_IIOException$nonrefs	_jc_javax_imageio_IIOException$nonrefs;
typedef struct _jc_javax_imageio_IIOException$object	_jc_javax_imageio_IIOException$object;

typedef const struct _jc_javax_imageio_IIOException$vmethods	_jc_javax_imageio_IIOException$vmethods;
typedef const struct _jc_javax_imageio_IIOException$vtable	_jc_javax_imageio_IIOException$vtable;
typedef const struct _jc_javax_imageio_IIOException$vtype	_jc_javax_imageio_IIOException$vtype;

// Constructors
extern void _jc_javax_imageio_IIOException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_IIOException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_IIOException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_imageio_IIOException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_imageio_IIOException$vmethods {
};

// Vtable
struct _jc_javax_imageio_IIOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_imageio_IIOException$vmethods	javax_imageio_IIOException;
};

// Vtype
struct _jc_javax_imageio_IIOException$vtype {
	_jc_type			type;
	_jc_javax_imageio_IIOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_IIOException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_IIOException$refs {
    _jc_javax_imageio_IIOException$sub_refs	javax_imageio_IIOException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_IIOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_IIOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_imageio_IIOException$sub_nonrefs	javax_imageio_IIOException;
};

// Object instance structure
struct _jc_javax_imageio_IIOException$object {
	_jc_javax_imageio_IIOException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_IIOException$vtype	*vtype;
	_jc_javax_imageio_IIOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_IIOException$vtype _jc_javax_imageio_IIOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_IIOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_IIOException$class_object;

#endif	/* _JC_javax_imageio_IIOException_H_ */
